@@ -1,7 +1,9 @@
 from abc import ABC, abstractmethod
+from typing import Any
 
 from pydantic import BaseModel
-from typing_extensions import Any, Union
+
+from dandy.consts import CACHE_DEFAULT_NAME
 
 
 class BaseCache(ABC, BaseModel):
@@ -13,22 +15,28 @@ class BaseCache(ABC, BaseModel):
         pass
 
     @abstractmethod
-    def get(self, key: str) -> Union[Any, None]:
+    def get(self, key: str) -> Any | None:
         pass
-    
+
     @abstractmethod
     def set(self, key: str, value: Any):
         pass
-    
+
     @abstractmethod
     def clean(self):
         pass
-    
+
+    @classmethod
     @abstractmethod
-    def clear(self):
+    def clear(cls, cache_name: str = CACHE_DEFAULT_NAME):
         pass
 
+    @classmethod
     @abstractmethod
-    def destroy(self):
+    def clear_all(cls):
         pass
 
+    @classmethod
+    @abstractmethod
+    def destroy_all(cls):
+        pass
