@@ -1,8 +1,9 @@
-from typing_extensions import OrderedDict, Union, Any
+from typing import OrderedDict, Any
 
+import dandy.consts
 from dandy.cache.cache import BaseCache
 
-_memory_cache = dict()
+_memory_cache = {}
 
 
 class MemoryCache(BaseCache):
@@ -10,7 +11,7 @@ class MemoryCache(BaseCache):
     limit: int
 
     @property
-    def _cache(self):
+    def _cache(self) -> OrderedDict:
         if self.cache_name not in _memory_cache:
             _memory_cache[self.cache_name] = OrderedDict()
 
@@ -19,7 +20,7 @@ class MemoryCache(BaseCache):
     def __len__(self) -> int:
         return len(self._cache)
 
-    def get(self, key: str) -> Union[Any, None]:
+    def get(self, key: str) -> Any | None:
         return self._cache.get(key)
 
     def set(self, key: str, value: Any):
@@ -30,8 +31,15 @@ class MemoryCache(BaseCache):
         if len(self._cache) > self.limit:
             self._cache.popitem(last=False)
 
-    def clear(self):
-        self._cache.clear()
+    @classmethod
+    def clear(cls, cache_name: str = dandy.consts.CACHE_DEFAULT_NAME):
+        if cache_name in _memory_cache:
+            _memory_cache[cache_name].clear()
 
-    def destroy(self):
-        self.clear()
\ No newline at end of file
+    @classmethod
+    def clear_all(cls):
+        _memory_cache.clear()
+
+    @classmethod
+    def destroy_all(cls):
+        cls.clear_all()
