@@ -1,17 +1,17 @@
 from types import NoneType
 
-from typing_extensions import get_origin, get_args, Type, List, Tuple, Set, Any, Union
+from typing import get_origin, get_args, Type, List, Tuple, Set, Any
 
 from dandy.intel.exceptions import IntelCriticalException
 
 
 class FieldAnnotation:
-    def __init__(self, annotation: Union[Type, None], field_name: str):
+    def __init__(self, annotation: Type | None, field_name: str):
         self.annotation = annotation
-        
+
         if self.first_inner_origin_is_iterable:
             self.annotation = self.first_inner
-        
+
         self.field_name = field_name
 
     @property
@@ -28,11 +28,13 @@ class FieldAnnotation:
 
         if len(inner) == 1:
             return inner[0]
-        elif len(inner) > 1:
-            raise IntelCriticalException(
+
+        if len(inner) > 1:
+            message = (
                 f'Failed to get annotation on field "{self.field_name}" because a "{self.origin}" had more than one '
-                f'non-None type or this fields annotation was beyond the complexity of 2 annotation origins.'
+                f'non-None type or this field\'s annotation was beyond the complexity of 2 annotation origins.'
             )
+            raise IntelCriticalException(message)
 
         return self.annotation
 
@@ -41,5 +43,5 @@ class FieldAnnotation:
         return get_origin(self.first_inner) in (list, List, tuple, Tuple, set, Set)
 
     @property
-    def origin(self) -> Union[Type, None]:
+    def origin(self) -> Type | None:
         return get_origin(self.annotation)
