@@ -1,4 +1,4 @@
-from dandy.constants import ESTIMATED_CHARACTERS_PER_TOKEN
+from dandy.consts import ESTIMATED_CHARACTERS_PER_TOKEN
 
 
 def get_estimated_token_count_for_string(string: str) -> int:
